pub struct DynamicFeeStruct {Show 13 fields
pub initialized: u8,
pub padding: [u8; 7],
pub max_volatility_accumulator: u32,
pub variable_fee_control: u32,
pub bin_step: u16,
pub filter_period: u16,
pub decay_period: u16,
pub reduction_factor: u16,
pub last_update_timestamp: u64,
pub bin_step_u128: u128,
pub sqrt_price_reference: u128,
pub volatility_accumulator: u128,
pub volatility_reference: u128,
}Fields
initialized: u8padding: [u8; 7]max_volatility_accumulator: u32variable_fee_control: u32bin_step: u16filter_period: u16decay_period: u16reduction_factor: u16last_update_timestamp: u64bin_step_u128: u128sqrt_price_reference: u128volatility_accumulator: u128volatility_reference: u128Trait Implementations
Sourceimpl BorshDeserialize for DynamicFeeStruct
impl BorshDeserialize for DynamicFeeStruct
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,